package com.ruoyi.system.service;

import java.util.List;

import com.ruoyi.system.domain.ActSuppliesRole;
import com.ruoyi.system.domain.ActSuppliesRoleDetail;

/**
 * 规则详情Service接口
 * 
 * @author dongjg
 * @date 2023-07-13
 */

public interface IActSuppliesRoleDetailService 
{
    /**
     * 查询规则详情
     * 
     * @param id 规则详情ID
     * @return 规则详情
     */
     ActSuppliesRoleDetail selectActSuppliesRoleDetailById(Integer id);

    /**
     * 查询规则详情列表
     * 
     * @param actSuppliesRoleDetail 规则详情
     * @return 规则详情集合
     */
     List<ActSuppliesRoleDetail> selectActSuppliesRoleDetailList(ActSuppliesRoleDetail actSuppliesRoleDetail);

    /**
     * 新增规则详情
     * 
     * @param actSuppliesRoleDetail 规则详情
     * @return 结果
     */
     int insertActSuppliesRoleDetail(ActSuppliesRoleDetail actSuppliesRoleDetail);

    /**
     * 修改规则详情
     * 
     * @param actSuppliesRoleDetail 规则详情
     * @return 结果
     */
     int updateActSuppliesRoleDetail(ActSuppliesRoleDetail actSuppliesRoleDetail);

    /**
     * 批量删除规则详情
     * 
     * @param ids 需要删除的规则详情ID
     * @return 结果
     */
     int deleteActSuppliesRoleDetailByIds(Integer[] ids);

    /**
     * 删除规则详情信息
     * 
     * @param id 规则详情ID
     * @return 结果
     */
     int deleteActSuppliesRoleDetailById(Integer id);

    List<ActSuppliesRole> saveSid();

//    List<ActOperation> saveOperation();

    /**
     * 启用物料细分类管理
     *
     * @param id  尝试启用物料细分类管理的id
     * @return
     */
    void setEnable(Long id);

    /**
     * 禁用
     *
     * @param id  尝试禁用物料细分类管理的id
     */
    void setDisable(Long id);

    List<ActSuppliesRole> saveSidsta();

}
